# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1NetworkPolicyPeer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ip_block': 'V1IPBlock',
        'namespace_selector': 'V1LabelSelector',
        'pod_selector': 'V1LabelSelector'
    }

    attribute_map = {
        'ip_block': 'ipBlock',
        'namespace_selector': 'namespaceSelector',
        'pod_selector': 'podSelector'
    }

    def __init__(self, ip_block=None, namespace_selector=None, pod_selector=None, local_vars_configuration=None):  # noqa: E501
        """V1NetworkPolicyPeer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._ip_block = None
        self._namespace_selector = None
        self._pod_selector = None
        self.discriminator = None

        if ip_block is not None:
            self.ip_block = ip_block
        if namespace_selector is not None:
            self.namespace_selector = namespace_selector
        if pod_selector is not None:
            self.pod_selector = pod_selector

    @property
    def ip_block(self):
        """Gets the ip_block of this V1NetworkPolicyPeer.  # noqa: E501


        :return: The ip_block of this V1NetworkPolicyPeer.  # noqa: E501
        :rtype: V1IPBlock
        """
        return self._ip_block

    @ip_block.setter
    def ip_block(self, ip_block):
        """Sets the ip_block of this V1NetworkPolicyPeer.


        :param ip_block: The ip_block of this V1NetworkPolicyPeer.  # noqa: E501
        :type ip_block: V1IPBlock
        """

        self._ip_block = ip_block

    @property
    def namespace_selector(self):
        """Gets the namespace_selector of this V1NetworkPolicyPeer.  # noqa: E501


        :return: The namespace_selector of this V1NetworkPolicyPeer.  # noqa: E501
        :rtype: V1LabelSelector
        """
        return self._namespace_selector

    @namespace_selector.setter
    def namespace_selector(self, namespace_selector):
        """Sets the namespace_selector of this V1NetworkPolicyPeer.


        :param namespace_selector: The namespace_selector of this V1NetworkPolicyPeer.  # noqa: E501
        :type namespace_selector: V1LabelSelector
        """

        self._namespace_selector = namespace_selector

    @property
    def pod_selector(self):
        """Gets the pod_selector of this V1NetworkPolicyPeer.  # noqa: E501


        :return: The pod_selector of this V1NetworkPolicyPeer.  # noqa: E501
        :rtype: V1LabelSelector
        """
        return self._pod_selector

    @pod_selector.setter
    def pod_selector(self, pod_selector):
        """Sets the pod_selector of this V1NetworkPolicyPeer.


        :param pod_selector: The pod_selector of this V1NetworkPolicyPeer.  # noqa: E501
        :type pod_selector: V1LabelSelector
        """

        self._pod_selector = pod_selector

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1NetworkPolicyPeer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1NetworkPolicyPeer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1MutatingAdmissionPolicyBindingSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'match_resources': 'V1MatchResources',
        'param_ref': 'V1ParamRef',
        'policy_name': 'str'
    }

    attribute_map = {
        'match_resources': 'matchResources',
        'param_ref': 'paramRef',
        'policy_name': 'policyName'
    }

    def __init__(self, match_resources=None, param_ref=None, policy_name=None, local_vars_configuration=None):  # noqa: E501
        """V1MutatingAdmissionPolicyBindingSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._match_resources = None
        self._param_ref = None
        self._policy_name = None
        self.discriminator = None

        if match_resources is not None:
            self.match_resources = match_resources
        if param_ref is not None:
            self.param_ref = param_ref
        if policy_name is not None:
            self.policy_name = policy_name

    @property
    def match_resources(self):
        """Gets the match_resources of this V1MutatingAdmissionPolicyBindingSpec.  # noqa: E501


        :return: The match_resources of this V1MutatingAdmissionPolicyBindingSpec.  # noqa: E501
        :rtype: V1MatchResources
        """
        return self._match_resources

    @match_resources.setter
    def match_resources(self, match_resources):
        """Sets the match_resources of this V1MutatingAdmissionPolicyBindingSpec.


        :param match_resources: The match_resources of this V1MutatingAdmissionPolicyBindingSpec.  # noqa: E501
        :type match_resources: V1MatchResources
        """

        self._match_resources = match_resources

    @property
    def param_ref(self):
        """Gets the param_ref of this V1MutatingAdmissionPolicyBindingSpec.  # noqa: E501


        :return: The param_ref of this V1MutatingAdmissionPolicyBindingSpec.  # noqa: E501
        :rtype: V1ParamRef
        """
        return self._param_ref

    @param_ref.setter
    def param_ref(self, param_ref):
        """Sets the param_ref of this V1MutatingAdmissionPolicyBindingSpec.


        :param param_ref: The param_ref of this V1MutatingAdmissionPolicyBindingSpec.  # noqa: E501
        :type param_ref: V1ParamRef
        """

        self._param_ref = param_ref

    @property
    def policy_name(self):
        """Gets the policy_name of this V1MutatingAdmissionPolicyBindingSpec.  # noqa: E501

        policyName references a MutatingAdmissionPolicy name which the MutatingAdmissionPolicyBinding binds to. If the referenced resource does not exist, this binding is considered invalid and will be ignored Required.  # noqa: E501

        :return: The policy_name of this V1MutatingAdmissionPolicyBindingSpec.  # noqa: E501
        :rtype: str
        """
        return self._policy_name

    @policy_name.setter
    def policy_name(self, policy_name):
        """Sets the policy_name of this V1MutatingAdmissionPolicyBindingSpec.

        policyName references a MutatingAdmissionPolicy name which the MutatingAdmissionPolicyBinding binds to. If the referenced resource does not exist, this binding is considered invalid and will be ignored Required.  # noqa: E501

        :param policy_name: The policy_name of this V1MutatingAdmissionPolicyBindingSpec.  # noqa: E501
        :type policy_name: str
        """

        self._policy_name = policy_name

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MutatingAdmissionPolicyBindingSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1MutatingAdmissionPolicyBindingSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from kubernetes.client.models.admissionregistration_v1_service_reference import AdmissionregistrationV1ServiceReference
from kubernetes.client.models.admissionregistration_v1_webhook_client_config import AdmissionregistrationV1WebhookClientConfig
from kubernetes.client.models.apiextensions_v1_service_reference import ApiextensionsV1ServiceReference
from kubernetes.client.models.apiextensions_v1_webhook_client_config import ApiextensionsV1WebhookClientConfig
from kubernetes.client.models.apiregistration_v1_service_reference import ApiregistrationV1ServiceReference
from kubernetes.client.models.authentication_v1_token_request import AuthenticationV1TokenRequest
from kubernetes.client.models.core_v1_endpoint_port import CoreV1EndpointPort
from kubernetes.client.models.core_v1_event import CoreV1Event
from kubernetes.client.models.core_v1_event_list import CoreV1EventList
from kubernetes.client.models.core_v1_event_series import CoreV1EventSeries
from kubernetes.client.models.core_v1_resource_claim import CoreV1ResourceClaim
from kubernetes.client.models.discovery_v1_endpoint_port import DiscoveryV1EndpointPort
from kubernetes.client.models.events_v1_event import EventsV1Event
from kubernetes.client.models.events_v1_event_list import EventsV1EventList
from kubernetes.client.models.events_v1_event_series import EventsV1EventSeries
from kubernetes.client.models.flowcontrol_v1_subject import FlowcontrolV1Subject
from kubernetes.client.models.rbac_v1_subject import RbacV1Subject
from kubernetes.client.models.resource_v1_resource_claim import ResourceV1ResourceClaim
from kubernetes.client.models.storage_v1_token_request import StorageV1TokenRequest
from kubernetes.client.models.v1_api_group import V1APIGroup
from kubernetes.client.models.v1_api_group_list import V1APIGroupList
from kubernetes.client.models.v1_api_resource import V1APIResource
from kubernetes.client.models.v1_api_resource_list import V1APIResourceList
from kubernetes.client.models.v1_api_service import V1APIService
from kubernetes.client.models.v1_api_service_condition import V1APIServiceCondition
from kubernetes.client.models.v1_api_service_list import V1APIServiceList
from kubernetes.client.models.v1_api_service_spec import V1APIServiceSpec
from kubernetes.client.models.v1_api_service_status import V1APIServiceStatus
from kubernetes.client.models.v1_api_versions import V1APIVersions
from kubernetes.client.models.v1_aws_elastic_block_store_volume_source import V1AWSElasticBlockStoreVolumeSource
from kubernetes.client.models.v1_affinity import V1Affinity
from kubernetes.client.models.v1_aggregation_rule import V1AggregationRule
from kubernetes.client.models.v1_allocated_device_status import V1AllocatedDeviceStatus
from kubernetes.client.models.v1_allocation_result import V1AllocationResult
from kubernetes.client.models.v1_app_armor_profile import V1AppArmorProfile
from kubernetes.client.models.v1_apply_configuration import V1ApplyConfiguration
from kubernetes.client.models.v1_attached_volume import V1AttachedVolume
from kubernetes.client.models.v1_audit_annotation import V1AuditAnnotation
from kubernetes.client.models.v1_azure_disk_volume_source import V1AzureDiskVolumeSource
from kubernetes.client.models.v1_azure_file_persistent_volume_source import V1AzureFilePersistentVolumeSource
from kubernetes.client.models.v1_azure_file_volume_source import V1AzureFileVolumeSource
from kubernetes.client.models.v1_binding import V1Binding
from kubernetes.client.models.v1_bound_object_reference import V1BoundObjectReference
from kubernetes.client.models.v1_cel_device_selector import V1CELDeviceSelector
from kubernetes.client.models.v1_csi_driver import V1CSIDriver
from kubernetes.client.models.v1_csi_driver_list import V1CSIDriverList
from kubernetes.client.models.v1_csi_driver_spec import V1CSIDriverSpec
from kubernetes.client.models.v1_csi_node import V1CSINode
from kubernetes.client.models.v1_csi_node_driver import V1CSINodeDriver
from kubernetes.client.models.v1_csi_node_list import V1CSINodeList
from kubernetes.client.models.v1_csi_node_spec import V1CSINodeSpec
from kubernetes.client.models.v1_csi_persistent_volume_source import V1CSIPersistentVolumeSource
from kubernetes.client.models.v1_csi_storage_capacity import V1CSIStorageCapacity
from kubernetes.client.models.v1_csi_storage_capacity_list import V1CSIStorageCapacityList
from kubernetes.client.models.v1_csi_volume_source import V1CSIVolumeSource
from kubernetes.client.models.v1_capabilities import V1Capabilities
from kubernetes.client.models.v1_capacity_request_policy import V1CapacityRequestPolicy
from kubernetes.client.models.v1_capacity_request_policy_range import V1CapacityRequestPolicyRange
from kubernetes.client.models.v1_capacity_requirements import V1CapacityRequirements
from kubernetes.client.models.v1_ceph_fs_persistent_volume_source import V1CephFSPersistentVolumeSource
from kubernetes.client.models.v1_ceph_fs_volume_source import V1CephFSVolumeSource
from kubernetes.client.models.v1_certificate_signing_request import V1CertificateSigningRequest
from kubernetes.client.models.v1_certificate_signing_request_condition import V1CertificateSigningRequestCondition
from kubernetes.client.models.v1_certificate_signing_request_list import V1CertificateSigningRequestList
from kubernetes.client.models.v1_certificate_signing_request_spec import V1CertificateSigningRequestSpec
from kubernetes.client.models.v1_certificate_signing_request_status import V1CertificateSigningRequestStatus
from kubernetes.client.models.v1_cinder_persistent_volume_source import V1CinderPersistentVolumeSource
from kubernetes.client.models.v1_cinder_volume_source import V1CinderVolumeSource
from kubernetes.client.models.v1_client_ip_config import V1ClientIPConfig
from kubernetes.client.models.v1_cluster_role import V1ClusterRole
from kubernetes.client.models.v1_cluster_role_binding import V1ClusterRoleBinding
from kubernetes.client.models.v1_cluster_role_binding_list import V1ClusterRoleBindingList
from kubernetes.client.models.v1_cluster_role_list import V1ClusterRoleList
from kubernetes.client.models.v1_cluster_trust_bundle_projection import V1ClusterTrustBundleProjection
from kubernetes.client.models.v1_component_condition import V1ComponentCondition
from kubernetes.client.models.v1_component_status import V1ComponentStatus
from kubernetes.client.models.v1_component_status_list import V1ComponentStatusList
from kubernetes.client.models.v1_condition import V1Condition
from kubernetes.client.models.v1_config_map import V1ConfigMap
from kubernetes.client.models.v1_config_map_env_source import V1ConfigMapEnvSource
from kubernetes.client.models.v1_config_map_key_selector import V1ConfigMapKeySelector
from kubernetes.client.models.v1_config_map_list import V1ConfigMapList
from kubernetes.client.models.v1_config_map_node_config_source import V1ConfigMapNodeConfigSource
from kubernetes.client.models.v1_config_map_projection import V1ConfigMapProjection
from kubernetes.client.models.v1_config_map_volume_source import V1ConfigMapVolumeSource
from kubernetes.client.models.v1_container import V1Container
from kubernetes.client.models.v1_container_extended_resource_request import V1ContainerExtendedResourceRequest
from kubernetes.client.models.v1_container_image import V1ContainerImage
from kubernetes.client.models.v1_container_port import V1ContainerPort
from kubernetes.client.models.v1_container_resize_policy import V1ContainerResizePolicy
from kubernetes.client.models.v1_container_restart_rule import V1ContainerRestartRule
from kubernetes.client.models.v1_container_restart_rule_on_exit_codes import V1ContainerRestartRuleOnExitCodes
from kubernetes.client.models.v1_container_state import V1ContainerState
from kubernetes.client.models.v1_container_state_running import V1ContainerStateRunning
from kubernetes.client.models.v1_container_state_terminated import V1ContainerStateTerminated
from kubernetes.client.models.v1_container_state_waiting import V1ContainerStateWaiting
from kubernetes.client.models.v1_container_status import V1ContainerStatus
from kubernetes.client.models.v1_container_user import V1ContainerUser
from kubernetes.client.models.v1_controller_revision import V1ControllerRevision
from kubernetes.client.models.v1_controller_revision_list import V1ControllerRevisionList
from kubernetes.client.models.v1_counter import V1Counter
from kubernetes.client.models.v1_counter_set import V1CounterSet
from kubernetes.client.models.v1_cron_job import V1CronJob
from kubernetes.client.models.v1_cron_job_list import V1CronJobList
from kubernetes.client.models.v1_cron_job_spec import V1CronJobSpec
from kubernetes.client.models.v1_cron_job_status import V1CronJobStatus
from kubernetes.client.models.v1_cross_version_object_reference import V1CrossVersionObjectReference
from kubernetes.client.models.v1_custom_resource_column_definition import V1CustomResourceColumnDefinition
from kubernetes.client.models.v1_custom_resource_conversion import V1CustomResourceConversion
from kubernetes.client.models.v1_custom_resource_definition import V1CustomResourceDefinition
from kubernetes.client.models.v1_custom_resource_definition_condition import V1CustomResourceDefinitionCondition
from kubernetes.client.models.v1_custom_resource_definition_list import V1CustomResourceDefinitionList
from kubernetes.client.models.v1_custom_resource_definition_names import V1CustomResourceDefinitionNames
from kubernetes.client.models.v1_custom_resource_definition_spec import V1CustomResourceDefinitionSpec
from kubernetes.client.models.v1_custom_resource_definition_status import V1CustomResourceDefinitionStatus
from kubernetes.client.models.v1_custom_resource_definition_version import V1CustomResourceDefinitionVersion
from kubernetes.client.models.v1_custom_resource_subresource_scale import V1CustomResourceSubresourceScale
from kubernetes.client.models.v1_custom_resource_subresources import V1CustomResourceSubresources
from kubernetes.client.models.v1_custom_resource_validation import V1CustomResourceValidation
from kubernetes.client.models.v1_daemon_endpoint import V1DaemonEndpoint
from kubernetes.client.models.v1_daemon_set import V1DaemonSet
from kubernetes.client.models.v1_daemon_set_condition import V1DaemonSetCondition
from kubernetes.client.models.v1_daemon_set_list import V1DaemonSetList
from kubernetes.client.models.v1_daemon_set_spec import V1DaemonSetSpec
from kubernetes.client.models.v1_daemon_set_status import V1DaemonSetStatus
from kubernetes.client.models.v1_daemon_set_update_strategy import V1DaemonSetUpdateStrategy
from kubernetes.client.models.v1_delete_options import V1DeleteOptions
from kubernetes.client.models.v1_deployment import V1Deployment
from kubernetes.client.models.v1_deployment_condition import V1DeploymentCondition
from kubernetes.client.models.v1_deployment_list import V1DeploymentList
from kubernetes.client.models.v1_deployment_spec import V1DeploymentSpec
from kubernetes.client.models.v1_deployment_status import V1DeploymentStatus
from kubernetes.client.models.v1_deployment_strategy import V1DeploymentStrategy
from kubernetes.client.models.v1_device import V1Device
from kubernetes.client.models.v1_device_allocation_configuration import V1DeviceAllocationConfiguration
from kubernetes.client.models.v1_device_allocation_result import V1DeviceAllocationResult
from kubernetes.client.models.v1_device_attribute import V1DeviceAttribute
from kubernetes.client.models.v1_device_capacity import V1DeviceCapacity
from kubernetes.client.models.v1_device_claim import V1DeviceClaim
from kubernetes.client.models.v1_device_claim_configuration import V1DeviceClaimConfiguration
from kubernetes.client.models.v1_device_class import V1DeviceClass
from kubernetes.client.models.v1_device_class_configuration import V1DeviceClassConfiguration
from kubernetes.client.models.v1_device_class_list import V1DeviceClassList
from kubernetes.client.models.v1_device_class_spec import V1DeviceClassSpec
from kubernetes.client.models.v1_device_constraint import V1DeviceConstraint
from kubernetes.client.models.v1_device_counter_consumption import V1DeviceCounterConsumption
from kubernetes.client.models.v1_device_request import V1DeviceRequest
from kubernetes.client.models.v1_device_request_allocation_result import V1DeviceRequestAllocationResult
from kubernetes.client.models.v1_device_selector import V1DeviceSelector
from kubernetes.client.models.v1_device_sub_request import V1DeviceSubRequest
from kubernetes.client.models.v1_device_taint import V1DeviceTaint
from kubernetes.client.models.v1_device_toleration import V1DeviceToleration
from kubernetes.client.models.v1_downward_api_projection import V1DownwardAPIProjection
from kubernetes.client.models.v1_downward_api_volume_file import V1DownwardAPIVolumeFile
from kubernetes.client.models.v1_downward_api_volume_source import V1DownwardAPIVolumeSource
from kubernetes.client.models.v1_empty_dir_volume_source import V1EmptyDirVolumeSource
from kubernetes.client.models.v1_endpoint import V1Endpoint
from kubernetes.client.models.v1_endpoint_address import V1EndpointAddress
from kubernetes.client.models.v1_endpoint_conditions import V1EndpointConditions
from kubernetes.client.models.v1_endpoint_hints import V1EndpointHints
from kubernetes.client.models.v1_endpoint_slice import V1EndpointSlice
from kubernetes.client.models.v1_endpoint_slice_list import V1EndpointSliceList
from kubernetes.client.models.v1_endpoint_subset import V1EndpointSubset
from kubernetes.client.models.v1_endpoints import V1Endpoints
from kubernetes.client.models.v1_endpoints_list import V1EndpointsList
from kubernetes.client.models.v1_env_from_source import V1EnvFromSource
from kubernetes.client.models.v1_env_var import V1EnvVar
from kubernetes.client.models.v1_env_var_source import V1EnvVarSource
from kubernetes.client.models.v1_ephemeral_container import V1EphemeralContainer
from kubernetes.client.models.v1_ephemeral_volume_source import V1EphemeralVolumeSource
from kubernetes.client.models.v1_event_source import V1EventSource
from kubernetes.client.models.v1_eviction import V1Eviction
from kubernetes.client.models.v1_exact_device_request import V1ExactDeviceRequest
from kubernetes.client.models.v1_exec_action import V1ExecAction
from kubernetes.client.models.v1_exempt_priority_level_configuration import V1ExemptPriorityLevelConfiguration
from kubernetes.client.models.v1_expression_warning import V1ExpressionWarning
from kubernetes.client.models.v1_external_documentation import V1ExternalDocumentation
from kubernetes.client.models.v1_fc_volume_source import V1FCVolumeSource
from kubernetes.client.models.v1_field_selector_attributes import V1FieldSelectorAttributes
from kubernetes.client.models.v1_field_selector_requirement import V1FieldSelectorRequirement
from kubernetes.client.models.v1_file_key_selector import V1FileKeySelector
from kubernetes.client.models.v1_flex_persistent_volume_source import V1FlexPersistentVolumeSource
from kubernetes.client.models.v1_flex_volume_source import V1FlexVolumeSource
from kubernetes.client.models.v1_flocker_volume_source import V1FlockerVolumeSource
from kubernetes.client.models.v1_flow_distinguisher_method import V1FlowDistinguisherMethod
from kubernetes.client.models.v1_flow_schema import V1FlowSchema
from kubernetes.client.models.v1_flow_schema_condition import V1FlowSchemaCondition
from kubernetes.client.models.v1_flow_schema_list import V1FlowSchemaList
from kubernetes.client.models.v1_flow_schema_spec import V1FlowSchemaSpec
from kubernetes.client.models.v1_flow_schema_status import V1FlowSchemaStatus
from kubernetes.client.models.v1_for_node import V1ForNode
from kubernetes.client.models.v1_for_zone import V1ForZone
from kubernetes.client.models.v1_gce_persistent_disk_volume_source import V1GCEPersistentDiskVolumeSource
from kubernetes.client.models.v1_grpc_action import V1GRPCAction
from kubernetes.client.models.v1_git_repo_volume_source import V1GitRepoVolumeSource
from kubernetes.client.models.v1_glusterfs_persistent_volume_source import V1GlusterfsPersistentVolumeSource
from kubernetes.client.models.v1_glusterfs_volume_source import V1GlusterfsVolumeSource
from kubernetes.client.models.v1_group_resource import V1GroupResource
from kubernetes.client.models.v1_group_subject import V1GroupSubject
from kubernetes.client.models.v1_group_version_for_discovery import V1GroupVersionForDiscovery
from kubernetes.client.models.v1_http_get_action import V1HTTPGetAction
from kubernetes.client.models.v1_http_header import V1HTTPHeader
from kubernetes.client.models.v1_http_ingress_path import V1HTTPIngressPath
from kubernetes.client.models.v1_http_ingress_rule_value import V1HTTPIngressRuleValue
from kubernetes.client.models.v1_horizontal_pod_autoscaler import V1HorizontalPodAutoscaler
from kubernetes.client.models.v1_horizontal_pod_autoscaler_list import V1HorizontalPodAutoscalerList
from kubernetes.client.models.v1_horizontal_pod_autoscaler_spec import V1HorizontalPodAutoscalerSpec
from kubernetes.client.models.v1_horizontal_pod_autoscaler_status import V1HorizontalPodAutoscalerStatus
from kubernetes.client.models.v1_host_alias import V1HostAlias
from kubernetes.client.models.v1_host_ip import V1HostIP
from kubernetes.client.models.v1_host_path_volume_source import V1HostPathVolumeSource
from kubernetes.client.models.v1_ip_address import V1IPAddress
from kubernetes.client.models.v1_ip_address_list import V1IPAddressList
from kubernetes.client.models.v1_ip_address_spec import V1IPAddressSpec
from kubernetes.client.models.v1_ip_block import V1IPBlock
from kubernetes.client.models.v1_iscsi_persistent_volume_source import V1ISCSIPersistentVolumeSource
from kubernetes.client.models.v1_iscsi_volume_source import V1ISCSIVolumeSource
from kubernetes.client.models.v1_image_volume_source import V1ImageVolumeSource
from kubernetes.client.models.v1_image_volume_status import V1ImageVolumeStatus
from kubernetes.client.models.v1_ingress import V1Ingress
from kubernetes.client.models.v1_ingress_backend import V1IngressBackend
from kubernetes.client.models.v1_ingress_class import V1IngressClass
from kubernetes.client.models.v1_ingress_class_list import V1IngressClassList
from kubernetes.client.models.v1_ingress_class_parameters_reference import V1IngressClassParametersReference
from kubernetes.client.models.v1_ingress_class_spec import V1IngressClassSpec
from kubernetes.client.models.v1_ingress_list import V1IngressList
from kubernetes.client.models.v1_ingress_load_balancer_ingress import V1IngressLoadBalancerIngress
from kubernetes.client.models.v1_ingress_load_balancer_status import V1IngressLoadBalancerStatus
from kubernetes.client.models.v1_ingress_port_status import V1IngressPortStatus
from kubernetes.client.models.v1_ingress_rule import V1IngressRule
from kubernetes.client.models.v1_ingress_service_backend import V1IngressServiceBackend
from kubernetes.client.models.v1_ingress_spec import V1IngressSpec
from kubernetes.client.models.v1_ingress_status import V1IngressStatus
from kubernetes.client.models.v1_ingress_tls import V1IngressTLS
from kubernetes.client.models.v1_json_patch import V1JSONPatch
from kubernetes.client.models.v1_json_schema_props import V1JSONSchemaProps
from kubernetes.client.models.v1_job import V1Job
from kubernetes.client.models.v1_job_condition import V1JobCondition
from kubernetes.client.models.v1_job_list import V1JobList
from kubernetes.client.models.v1_job_spec import V1JobSpec
from kubernetes.client.models.v1_job_status import V1JobStatus
from kubernetes.client.models.v1_job_template_spec import V1JobTemplateSpec
from kubernetes.client.models.v1_key_to_path import V1KeyToPath
from kubernetes.client.models.v1_label_selector import V1LabelSelector
from kubernetes.client.models.v1_label_selector_attributes import V1LabelSelectorAttributes
from kubernetes.client.models.v1_label_selector_requirement import V1LabelSelectorRequirement
from kubernetes.client.models.v1_lease import V1Lease
from kubernetes.client.models.v1_lease_list import V1LeaseList
from kubernetes.client.models.v1_lease_spec import V1LeaseSpec
from kubernetes.client.models.v1_lifecycle import V1Lifecycle
from kubernetes.client.models.v1_lifecycle_handler import V1LifecycleHandler
from kubernetes.client.models.v1_limit_range import V1LimitRange
from kubernetes.client.models.v1_limit_range_item import V1LimitRangeItem
from kubernetes.client.models.v1_limit_range_list import V1LimitRangeList
from kubernetes.client.models.v1_limit_range_spec import V1LimitRangeSpec
from kubernetes.client.models.v1_limit_response import V1LimitResponse
from kubernetes.client.models.v1_limited_priority_level_configuration import V1LimitedPriorityLevelConfiguration
from kubernetes.client.models.v1_linux_container_user import V1LinuxContainerUser
from kubernetes.client.models.v1_list_meta import V1ListMeta
from kubernetes.client.models.v1_load_balancer_ingress import V1LoadBalancerIngress
from kubernetes.client.models.v1_load_balancer_status import V1LoadBalancerStatus
from kubernetes.client.models.v1_local_object_reference import V1LocalObjectReference
from kubernetes.client.models.v1_local_subject_access_review import V1LocalSubjectAccessReview
from kubernetes.client.models.v1_local_volume_source import V1LocalVolumeSource
from kubernetes.client.models.v1_managed_fields_entry import V1ManagedFieldsEntry
from kubernetes.client.models.v1_match_condition import V1MatchCondition
from kubernetes.client.models.v1_match_resources import V1MatchResources
from kubernetes.client.models.v1_modify_volume_status import V1ModifyVolumeStatus
from kubernetes.client.models.v1_mutating_admission_policy import V1MutatingAdmissionPolicy
from kubernetes.client.models.v1_mutating_admission_policy_binding import V1MutatingAdmissionPolicyBinding
from kubernetes.client.models.v1_mutating_admission_policy_binding_list import V1MutatingAdmissionPolicyBindingList
from kubernetes.client.models.v1_mutating_admission_policy_binding_spec import V1MutatingAdmissionPolicyBindingSpec
from kubernetes.client.models.v1_mutating_admission_policy_list import V1MutatingAdmissionPolicyList
from kubernetes.client.models.v1_mutating_admission_policy_spec import V1MutatingAdmissionPolicySpec
from kubernetes.client.models.v1_mutating_webhook import V1MutatingWebhook
from kubernetes.client.models.v1_mutating_webhook_configuration import V1MutatingWebhookConfiguration
from kubernetes.client.models.v1_mutating_webhook_configuration_list import V1MutatingWebhookConfigurationList
from kubernetes.client.models.v1_mutation import V1Mutation
from kubernetes.client.models.v1_nfs_volume_source import V1NFSVolumeSource
from kubernetes.client.models.v1_named_rule_with_operations import V1NamedRuleWithOperations
from kubernetes.client.models.v1_namespace import V1Namespace
from kubernetes.client.models.v1_namespace_condition import V1NamespaceCondition
from kubernetes.client.models.v1_namespace_list import V1NamespaceList
from kubernetes.client.models.v1_namespace_spec import V1NamespaceSpec
from kubernetes.client.models.v1_namespace_status import V1NamespaceStatus
from kubernetes.client.models.v1_network_device_data import V1NetworkDeviceData
from kubernetes.client.models.v1_network_policy import V1NetworkPolicy
from kubernetes.client.models.v1_network_policy_egress_rule import V1NetworkPolicyEgressRule
from kubernetes.client.models.v1_network_policy_ingress_rule import V1NetworkPolicyIngressRule
from kubernetes.client.models.v1_network_policy_list import V1NetworkPolicyList
from kubernetes.client.models.v1_network_policy_peer import V1NetworkPolicyPeer
from kubernetes.client.models.v1_network_policy_port import V1NetworkPolicyPort
from kubernetes.client.models.v1_network_policy_spec import V1NetworkPolicySpec
from kubernetes.client.models.v1_node import V1Node
from kubernetes.client.models.v1_node_address import V1NodeAddress
from kubernetes.client.models.v1_node_affinity import V1NodeAffinity
from kubernetes.client.models.v1_node_allocatable_resource_claim_status import V1NodeAllocatableResourceClaimStatus
from kubernetes.client.models.v1_node_allocatable_resource_mapping import V1NodeAllocatableResourceMapping
from kubernetes.client.models.v1_node_condition import V1NodeCondition
from kubernetes.client.models.v1_node_config_source import V1NodeConfigSource
from kubernetes.client.models.v1_node_config_status import V1NodeConfigStatus
from kubernetes.client.models.v1_node_daemon_endpoints import V1NodeDaemonEndpoints
from kubernetes.client.models.v1_node_features import V1NodeFeatures
from kubernetes.client.models.v1_node_list import V1NodeList
from kubernetes.client.models.v1_node_runtime_handler import V1NodeRuntimeHandler
from kubernetes.client.models.v1_node_runtime_handler_features import V1NodeRuntimeHandlerFeatures
from kubernetes.client.models.v1_node_selector import V1NodeSelector
from kubernetes.client.models.v1_node_selector_requirement import V1NodeSelectorRequirement
from kubernetes.client.models.v1_node_selector_term import V1NodeSelectorTerm
from kubernetes.client.models.v1_node_spec import V1NodeSpec
from kubernetes.client.models.v1_node_status import V1NodeStatus
from kubernetes.client.models.v1_node_swap_status import V1NodeSwapStatus
from kubernetes.client.models.v1_node_system_info import V1NodeSystemInfo
from kubernetes.client.models.v1_non_resource_attributes import V1NonResourceAttributes
from kubernetes.client.models.v1_non_resource_policy_rule import V1NonResourcePolicyRule
from kubernetes.client.models.v1_non_resource_rule import V1NonResourceRule
from kubernetes.client.models.v1_object_field_selector import V1ObjectFieldSelector
from kubernetes.client.models.v1_object_meta import V1ObjectMeta
from kubernetes.client.models.v1_object_reference import V1ObjectReference
from kubernetes.client.models.v1_opaque_device_configuration import V1OpaqueDeviceConfiguration
from kubernetes.client.models.v1_overhead import V1Overhead
from kubernetes.client.models.v1_owner_reference import V1OwnerReference
from kubernetes.client.models.v1_param_kind import V1ParamKind
from kubernetes.client.models.v1_param_ref import V1ParamRef
from kubernetes.client.models.v1_parent_reference import V1ParentReference
from kubernetes.client.models.v1_persistent_volume import V1PersistentVolume
from kubernetes.client.models.v1_persistent_volume_claim import V1PersistentVolumeClaim
from kubernetes.client.models.v1_persistent_volume_claim_condition import V1PersistentVolumeClaimCondition
from kubernetes.client.models.v1_persistent_volume_claim_list import V1PersistentVolumeClaimList
from kubernetes.client.models.v1_persistent_volume_claim_spec import V1PersistentVolumeClaimSpec
from kubernetes.client.models.v1_persistent_volume_claim_status import V1PersistentVolumeClaimStatus
from kubernetes.client.models.v1_persistent_volume_claim_template import V1PersistentVolumeClaimTemplate
from kubernetes.client.models.v1_persistent_volume_claim_volume_source import V1PersistentVolumeClaimVolumeSource
from kubernetes.client.models.v1_persistent_volume_list import V1PersistentVolumeList
from kubernetes.client.models.v1_persistent_volume_spec import V1PersistentVolumeSpec
from kubernetes.client.models.v1_persistent_volume_status import V1PersistentVolumeStatus
from kubernetes.client.models.v1_photon_persistent_disk_volume_source import V1PhotonPersistentDiskVolumeSource
from kubernetes.client.models.v1_pod import V1Pod
from kubernetes.client.models.v1_pod_affinity import V1PodAffinity
from kubernetes.client.models.v1_pod_affinity_term import V1PodAffinityTerm
from kubernetes.client.models.v1_pod_anti_affinity import V1PodAntiAffinity
from kubernetes.client.models.v1_pod_certificate_projection import V1PodCertificateProjection
from kubernetes.client.models.v1_pod_condition import V1PodCondition
from kubernetes.client.models.v1_pod_dns_config import V1PodDNSConfig
from kubernetes.client.models.v1_pod_dns_config_option import V1PodDNSConfigOption
from kubernetes.client.models.v1_pod_disruption_budget import V1PodDisruptionBudget
from kubernetes.client.models.v1_pod_disruption_budget_list import V1PodDisruptionBudgetList
from kubernetes.client.models.v1_pod_disruption_budget_spec import V1PodDisruptionBudgetSpec
from kubernetes.client.models.v1_pod_disruption_budget_status import V1PodDisruptionBudgetStatus
from kubernetes.client.models.v1_pod_extended_resource_claim_status import V1PodExtendedResourceClaimStatus
from kubernetes.client.models.v1_pod_failure_policy import V1PodFailurePolicy
from kubernetes.client.models.v1_pod_failure_policy_on_exit_codes_requirement import V1PodFailurePolicyOnExitCodesRequirement
from kubernetes.client.models.v1_pod_failure_policy_on_pod_conditions_pattern import V1PodFailurePolicyOnPodConditionsPattern
from kubernetes.client.models.v1_pod_failure_policy_rule import V1PodFailurePolicyRule
from kubernetes.client.models.v1_pod_ip import V1PodIP
from kubernetes.client.models.v1_pod_list import V1PodList
from kubernetes.client.models.v1_pod_os import V1PodOS
from kubernetes.client.models.v1_pod_readiness_gate import V1PodReadinessGate
from kubernetes.client.models.v1_pod_resource_claim import V1PodResourceClaim
from kubernetes.client.models.v1_pod_resource_claim_status import V1PodResourceClaimStatus
from kubernetes.client.models.v1_pod_scheduling_gate import V1PodSchedulingGate
from kubernetes.client.models.v1_pod_scheduling_group import V1PodSchedulingGroup
from kubernetes.client.models.v1_pod_security_context import V1PodSecurityContext
from kubernetes.client.models.v1_pod_spec import V1PodSpec
from kubernetes.client.models.v1_pod_status import V1PodStatus
from kubernetes.client.models.v1_pod_template import V1PodTemplate
from kubernetes.client.models.v1_pod_template_list import V1PodTemplateList
from kubernetes.client.models.v1_pod_template_spec import V1PodTemplateSpec
from kubernetes.client.models.v1_policy_rule import V1PolicyRule
from kubernetes.client.models.v1_policy_rules_with_subjects import V1PolicyRulesWithSubjects
from kubernetes.client.models.v1_port_status import V1PortStatus
from kubernetes.client.models.v1_portworx_volume_source import V1PortworxVolumeSource
from kubernetes.client.models.v1_preconditions import V1Preconditions
from kubernetes.client.models.v1_preferred_scheduling_term import V1PreferredSchedulingTerm
from kubernetes.client.models.v1_priority_class import V1PriorityClass
from kubernetes.client.models.v1_priority_class_list import V1PriorityClassList
from kubernetes.client.models.v1_priority_level_configuration import V1PriorityLevelConfiguration
from kubernetes.client.models.v1_priority_level_configuration_condition import V1PriorityLevelConfigurationCondition
from kubernetes.client.models.v1_priority_level_configuration_list import V1PriorityLevelConfigurationList
from kubernetes.client.models.v1_priority_level_configuration_reference import V1PriorityLevelConfigurationReference
from kubernetes.client.models.v1_priority_level_configuration_spec import V1PriorityLevelConfigurationSpec
from kubernetes.client.models.v1_priority_level_configuration_status import V1PriorityLevelConfigurationStatus
from kubernetes.client.models.v1_probe import V1Probe
from kubernetes.client.models.v1_projected_volume_source import V1ProjectedVolumeSource
from kubernetes.client.models.v1_queuing_configuration import V1QueuingConfiguration
from kubernetes.client.models.v1_quobyte_volume_source import V1QuobyteVolumeSource
from kubernetes.client.models.v1_rbd_persistent_volume_source import V1RBDPersistentVolumeSource
from kubernetes.client.models.v1_rbd_volume_source import V1RBDVolumeSource
from kubernetes.client.models.v1_replica_set import V1ReplicaSet
from kubernetes.client.models.v1_replica_set_condition import V1ReplicaSetCondition
from kubernetes.client.models.v1_replica_set_list import V1ReplicaSetList
from kubernetes.client.models.v1_replica_set_spec import V1ReplicaSetSpec
from kubernetes.client.models.v1_replica_set_status import V1ReplicaSetStatus
from kubernetes.client.models.v1_replication_controller import V1ReplicationController
from kubernetes.client.models.v1_replication_controller_condition import V1ReplicationControllerCondition
from kubernetes.client.models.v1_replication_controller_list import V1ReplicationControllerList
from kubernetes.client.models.v1_replication_controller_spec import V1ReplicationControllerSpec
from kubernetes.client.models.v1_replication_controller_status import V1ReplicationControllerStatus
from kubernetes.client.models.v1_resource_attributes import V1ResourceAttributes
from kubernetes.client.models.v1_resource_claim_consumer_reference import V1ResourceClaimConsumerReference
from kubernetes.client.models.v1_resource_claim_list import V1ResourceClaimList
from kubernetes.client.models.v1_resource_claim_spec import V1ResourceClaimSpec
from kubernetes.client.models.v1_resource_claim_status import V1ResourceClaimStatus
from kubernetes.client.models.v1_resource_claim_template import V1ResourceClaimTemplate
from kubernetes.client.models.v1_resource_claim_template_list import V1ResourceClaimTemplateList
from kubernetes.client.models.v1_resource_claim_template_spec import V1ResourceClaimTemplateSpec
from kubernetes.client.models.v1_resource_field_selector import V1ResourceFieldSelector
from kubernetes.client.models.v1_resource_health import V1ResourceHealth
from kubernetes.client.models.v1_resource_policy_rule import V1ResourcePolicyRule
from kubernetes.client.models.v1_resource_pool import V1ResourcePool
from kubernetes.client.models.v1_resource_quota import V1ResourceQuota
from kubernetes.client.models.v1_resource_quota_list import V1ResourceQuotaList
from kubernetes.client.models.v1_resource_quota_spec import V1ResourceQuotaSpec
from kubernetes.client.models.v1_resource_quota_status import V1ResourceQuotaStatus
from kubernetes.client.models.v1_resource_requirements import V1ResourceRequirements
from kubernetes.client.models.v1_resource_rule import V1ResourceRule
from kubernetes.client.models.v1_resource_slice import V1ResourceSlice
from kubernetes.client.models.v1_resource_slice_list import V1ResourceSliceList
from kubernetes.client.models.v1_resource_slice_spec import V1ResourceSliceSpec
from kubernetes.client.models.v1_resource_status import V1ResourceStatus
from kubernetes.client.models.v1_role import V1Role
from kubernetes.client.models.v1_role_binding import V1RoleBinding
from kubernetes.client.models.v1_role_binding_list import V1RoleBindingList
from kubernetes.client.models.v1_role_list import V1RoleList
from kubernetes.client.models.v1_role_ref import V1RoleRef
from kubernetes.client.models.v1_rolling_update_daemon_set import V1RollingUpdateDaemonSet
from kubernetes.client.models.v1_rolling_update_deployment import V1RollingUpdateDeployment
from kubernetes.client.models.v1_rolling_update_stateful_set_strategy import V1RollingUpdateStatefulSetStrategy
from kubernetes.client.models.v1_rule_with_operations import V1RuleWithOperations
from kubernetes.client.models.v1_runtime_class import V1RuntimeClass
from kubernetes.client.models.v1_runtime_class_list import V1RuntimeClassList
from kubernetes.client.models.v1_se_linux_options import V1SELinuxOptions
from kubernetes.client.models.v1_scale import V1Scale
from kubernetes.client.models.v1_scale_io_persistent_volume_source import V1ScaleIOPersistentVolumeSource
from kubernetes.client.models.v1_scale_io_volume_source import V1ScaleIOVolumeSource
from kubernetes.client.models.v1_scale_spec import V1ScaleSpec
from kubernetes.client.models.v1_scale_status import V1ScaleStatus
from kubernetes.client.models.v1_scheduling import V1Scheduling
from kubernetes.client.models.v1_scope_selector import V1ScopeSelector
from kubernetes.client.models.v1_scoped_resource_selector_requirement import V1ScopedResourceSelectorRequirement
from kubernetes.client.models.v1_seccomp_profile import V1SeccompProfile
from kubernetes.client.models.v1_secret import V1Secret
from kubernetes.client.models.v1_secret_env_source import V1SecretEnvSource
from kubernetes.client.models.v1_secret_key_selector import V1SecretKeySelector
from kubernetes.client.models.v1_secret_list import V1SecretList
from kubernetes.client.models.v1_secret_projection import V1SecretProjection
from kubernetes.client.models.v1_secret_reference import V1SecretReference
from kubernetes.client.models.v1_secret_volume_source import V1SecretVolumeSource
from kubernetes.client.models.v1_security_context import V1SecurityContext
from kubernetes.client.models.v1_selectable_field import V1SelectableField
from kubernetes.client.models.v1_self_subject_access_review import V1SelfSubjectAccessReview
from kubernetes.client.models.v1_self_subject_access_review_spec import V1SelfSubjectAccessReviewSpec
from kubernetes.client.models.v1_self_subject_review import V1SelfSubjectReview
from kubernetes.client.models.v1_self_subject_review_status import V1SelfSubjectReviewStatus
from kubernetes.client.models.v1_self_subject_rules_review import V1SelfSubjectRulesReview
from kubernetes.client.models.v1_self_subject_rules_review_spec import V1SelfSubjectRulesReviewSpec
from kubernetes.client.models.v1_server_address_by_client_cidr import V1ServerAddressByClientCIDR
from kubernetes.client.models.v1_service import V1Service
from kubernetes.client.models.v1_service_account import V1ServiceAccount
from kubernetes.client.models.v1_service_account_list import V1ServiceAccountList
from kubernetes.client.models.v1_service_account_subject import V1ServiceAccountSubject
from kubernetes.client.models.v1_service_account_token_projection import V1ServiceAccountTokenProjection
from kubernetes.client.models.v1_service_backend_port import V1ServiceBackendPort
from kubernetes.client.models.v1_service_cidr import V1ServiceCIDR
from kubernetes.client.models.v1_service_cidr_list import V1ServiceCIDRList
from kubernetes.client.models.v1_service_cidr_spec import V1ServiceCIDRSpec
from kubernetes.client.models.v1_service_cidr_status import V1ServiceCIDRStatus
from kubernetes.client.models.v1_service_list import V1ServiceList
from kubernetes.client.models.v1_service_port import V1ServicePort
from kubernetes.client.models.v1_service_spec import V1ServiceSpec
from kubernetes.client.models.v1_service_status import V1ServiceStatus
from kubernetes.client.models.v1_session_affinity_config import V1SessionAffinityConfig
from kubernetes.client.models.v1_shard_info import V1ShardInfo
from kubernetes.client.models.v1_sleep_action import V1SleepAction
from kubernetes.client.models.v1_stateful_set import V1StatefulSet
from kubernetes.client.models.v1_stateful_set_condition import V1StatefulSetCondition
from kubernetes.client.models.v1_stateful_set_list import V1StatefulSetList
from kubernetes.client.models.v1_stateful_set_ordinals import V1StatefulSetOrdinals
from kubernetes.client.models.v1_stateful_set_persistent_volume_claim_retention_policy import V1StatefulSetPersistentVolumeClaimRetentionPolicy
from kubernetes.client.models.v1_stateful_set_spec import V1StatefulSetSpec
from kubernetes.client.models.v1_stateful_set_status import V1StatefulSetStatus
from kubernetes.client.models.v1_stateful_set_update_strategy import V1StatefulSetUpdateStrategy
from kubernetes.client.models.v1_status import V1Status
from kubernetes.client.models.v1_status_cause import V1StatusCause
from kubernetes.client.models.v1_status_details import V1StatusDetails
from kubernetes.client.models.v1_storage_class import V1StorageClass
from kubernetes.client.models.v1_storage_class_list import V1StorageClassList
from kubernetes.client.models.v1_storage_os_persistent_volume_source import V1StorageOSPersistentVolumeSource
from kubernetes.client.models.v1_storage_os_volume_source import V1StorageOSVolumeSource
from kubernetes.client.models.v1_subject_access_review import V1SubjectAccessReview
from kubernetes.client.models.v1_subject_access_review_spec import V1SubjectAccessReviewSpec
from kubernetes.client.models.v1_subject_access_review_status import V1SubjectAccessReviewStatus
from kubernetes.client.models.v1_subject_rules_review_status import V1SubjectRulesReviewStatus
from kubernetes.client.models.v1_success_policy import V1SuccessPolicy
from kubernetes.client.models.v1_success_policy_rule import V1SuccessPolicyRule
from kubernetes.client.models.v1_sysctl import V1Sysctl
from kubernetes.client.models.v1_tcp_socket_action import V1TCPSocketAction
from kubernetes.client.models.v1_taint import V1Taint
from kubernetes.client.models.v1_token_request_spec import V1TokenRequestSpec
from kubernetes.client.models.v1_token_request_status import V1TokenRequestStatus
from kubernetes.client.models.v1_token_review import V1TokenReview
from kubernetes.client.models.v1_token_review_spec import V1TokenReviewSpec
from kubernetes.client.models.v1_token_review_status import V1TokenReviewStatus
from kubernetes.client.models.v1_toleration import V1Toleration
from kubernetes.client.models.v1_topology_selector_label_requirement import V1TopologySelectorLabelRequirement
from kubernetes.client.models.v1_topology_selector_term import V1TopologySelectorTerm
from kubernetes.client.models.v1_topology_spread_constraint import V1TopologySpreadConstraint
from kubernetes.client.models.v1_type_checking import V1TypeChecking
from kubernetes.client.models.v1_typed_local_object_reference import V1TypedLocalObjectReference
from kubernetes.client.models.v1_typed_object_reference import V1TypedObjectReference
from kubernetes.client.models.v1_uncounted_terminated_pods import V1UncountedTerminatedPods
from kubernetes.client.models.v1_user_info import V1UserInfo
from kubernetes.client.models.v1_user_subject import V1UserSubject
from kubernetes.client.models.v1_validating_admission_policy import V1ValidatingAdmissionPolicy
from kubernetes.client.models.v1_validating_admission_policy_binding import V1ValidatingAdmissionPolicyBinding
from kubernetes.client.models.v1_validating_admission_policy_binding_list import V1ValidatingAdmissionPolicyBindingList
from kubernetes.client.models.v1_validating_admission_policy_binding_spec import V1ValidatingAdmissionPolicyBindingSpec
from kubernetes.client.models.v1_validating_admission_policy_list import V1ValidatingAdmissionPolicyList
from kubernetes.client.models.v1_validating_admission_policy_spec import V1ValidatingAdmissionPolicySpec
from kubernetes.client.models.v1_validating_admission_policy_status import V1ValidatingAdmissionPolicyStatus
from kubernetes.client.models.v1_validating_webhook import V1ValidatingWebhook
from kubernetes.client.models.v1_validating_webhook_configuration import V1ValidatingWebhookConfiguration
from kubernetes.client.models.v1_validating_webhook_configuration_list import V1ValidatingWebhookConfigurationList
from kubernetes.client.models.v1_validation import V1Validation
from kubernetes.client.models.v1_validation_rule import V1ValidationRule
from kubernetes.client.models.v1_variable import V1Variable
from kubernetes.client.models.v1_volume import V1Volume
from kubernetes.client.models.v1_volume_attachment import V1VolumeAttachment
from kubernetes.client.models.v1_volume_attachment_list import V1VolumeAttachmentList
from kubernetes.client.models.v1_volume_attachment_source import V1VolumeAttachmentSource
from kubernetes.client.models.v1_volume_attachment_spec import V1VolumeAttachmentSpec
from kubernetes.client.models.v1_volume_attachment_status import V1VolumeAttachmentStatus
from kubernetes.client.models.v1_volume_attributes_class import V1VolumeAttributesClass
from kubernetes.client.models.v1_volume_attributes_class_list import V1VolumeAttributesClassList
from kubernetes.client.models.v1_volume_device import V1VolumeDevice
from kubernetes.client.models.v1_volume_error import V1VolumeError
from kubernetes.client.models.v1_volume_mount import V1VolumeMount
from kubernetes.client.models.v1_volume_mount_status import V1VolumeMountStatus
from kubernetes.client.models.v1_volume_node_affinity import V1VolumeNodeAffinity
from kubernetes.client.models.v1_volume_node_resources import V1VolumeNodeResources
from kubernetes.client.models.v1_volume_projection import V1VolumeProjection
from kubernetes.client.models.v1_volume_resource_requirements import V1VolumeResourceRequirements
from kubernetes.client.models.v1_volume_status import V1VolumeStatus
from kubernetes.client.models.v1_vsphere_virtual_disk_volume_source import V1VsphereVirtualDiskVolumeSource
from kubernetes.client.models.v1_watch_event import V1WatchEvent
from kubernetes.client.models.v1_webhook_conversion import V1WebhookConversion
from kubernetes.client.models.v1_weighted_pod_affinity_term import V1WeightedPodAffinityTerm
from kubernetes.client.models.v1_windows_security_context_options import V1WindowsSecurityContextOptions
from kubernetes.client.models.v1alpha1_apply_configuration import V1alpha1ApplyConfiguration
from kubernetes.client.models.v1alpha1_cluster_trust_bundle import V1alpha1ClusterTrustBundle
from kubernetes.client.models.v1alpha1_cluster_trust_bundle_list import V1alpha1ClusterTrustBundleList
from kubernetes.client.models.v1alpha1_cluster_trust_bundle_spec import V1alpha1ClusterTrustBundleSpec
from kubernetes.client.models.v1alpha1_json_patch import V1alpha1JSONPatch
from kubernetes.client.models.v1alpha1_match_condition import V1alpha1MatchCondition
from kubernetes.client.models.v1alpha1_match_resources import V1alpha1MatchResources
from kubernetes.client.models.v1alpha1_mutating_admission_policy import V1alpha1MutatingAdmissionPolicy
from kubernetes.client.models.v1alpha1_mutating_admission_policy_binding import V1alpha1MutatingAdmissionPolicyBinding
from kubernetes.client.models.v1alpha1_mutating_admission_policy_binding_list import V1alpha1MutatingAdmissionPolicyBindingList
from kubernetes.client.models.v1alpha1_mutating_admission_policy_binding_spec import V1alpha1MutatingAdmissionPolicyBindingSpec
from kubernetes.client.models.v1alpha1_mutating_admission_policy_list import V1alpha1MutatingAdmissionPolicyList
from kubernetes.client.models.v1alpha1_mutating_admission_policy_spec import V1alpha1MutatingAdmissionPolicySpec
from kubernetes.client.models.v1alpha1_mutation import V1alpha1Mutation
from kubernetes.client.models.v1alpha1_named_rule_with_operations import V1alpha1NamedRuleWithOperations
from kubernetes.client.models.v1alpha1_param_kind import V1alpha1ParamKind
from kubernetes.client.models.v1alpha1_param_ref import V1alpha1ParamRef
from kubernetes.client.models.v1alpha1_server_storage_version import V1alpha1ServerStorageVersion
from kubernetes.client.models.v1alpha1_storage_version import V1alpha1StorageVersion
from kubernetes.client.models.v1alpha1_storage_version_condition import V1alpha1StorageVersionCondition
from kubernetes.client.models.v1alpha1_storage_version_list import V1alpha1StorageVersionList
from kubernetes.client.models.v1alpha1_storage_version_status import V1alpha1StorageVersionStatus
from kubernetes.client.models.v1alpha1_variable import V1alpha1Variable
from kubernetes.client.models.v1alpha2_gang_scheduling_policy import V1alpha2GangSchedulingPolicy
from kubernetes.client.models.v1alpha2_lease_candidate import V1alpha2LeaseCandidate
from kubernetes.client.models.v1alpha2_lease_candidate_list import V1alpha2LeaseCandidateList
from kubernetes.client.models.v1alpha2_lease_candidate_spec import V1alpha2LeaseCandidateSpec
from kubernetes.client.models.v1alpha2_pod_group import V1alpha2PodGroup
from kubernetes.client.models.v1alpha2_pod_group_list import V1alpha2PodGroupList
from kubernetes.client.models.v1alpha2_pod_group_resource_claim import V1alpha2PodGroupResourceClaim
from kubernetes.client.models.v1alpha2_pod_group_resource_claim_status import V1alpha2PodGroupResourceClaimStatus
from kubernetes.client.models.v1alpha2_pod_group_scheduling_constraints import V1alpha2PodGroupSchedulingConstraints
from kubernetes.client.models.v1alpha2_pod_group_scheduling_policy import V1alpha2PodGroupSchedulingPolicy
from kubernetes.client.models.v1alpha2_pod_group_spec import V1alpha2PodGroupSpec
from kubernetes.client.models.v1alpha2_pod_group_status import V1alpha2PodGroupStatus
from kubernetes.client.models.v1alpha2_pod_group_template import V1alpha2PodGroupTemplate
from kubernetes.client.models.v1alpha2_pod_group_template_reference import V1alpha2PodGroupTemplateReference
from kubernetes.client.models.v1alpha2_topology_constraint import V1alpha2TopologyConstraint
from kubernetes.client.models.v1alpha2_typed_local_object_reference import V1alpha2TypedLocalObjectReference
from kubernetes.client.models.v1alpha2_workload import V1alpha2Workload
from kubernetes.client.models.v1alpha2_workload_list import V1alpha2WorkloadList
from kubernetes.client.models.v1alpha2_workload_pod_group_template_reference import V1alpha2WorkloadPodGroupTemplateReference
from kubernetes.client.models.v1alpha2_workload_spec import V1alpha2WorkloadSpec
from kubernetes.client.models.v1alpha3_device_taint import V1alpha3DeviceTaint
from kubernetes.client.models.v1alpha3_device_taint_rule import V1alpha3DeviceTaintRule
from kubernetes.client.models.v1alpha3_device_taint_rule_list import V1alpha3DeviceTaintRuleList
from kubernetes.client.models.v1alpha3_device_taint_rule_spec import V1alpha3DeviceTaintRuleSpec
from kubernetes.client.models.v1alpha3_device_taint_rule_status import V1alpha3DeviceTaintRuleStatus
from kubernetes.client.models.v1alpha3_device_taint_selector import V1alpha3DeviceTaintSelector
from kubernetes.client.models.v1alpha3_pool_status import V1alpha3PoolStatus
from kubernetes.client.models.v1alpha3_resource_pool_status_request import V1alpha3ResourcePoolStatusRequest
from kubernetes.client.models.v1alpha3_resource_pool_status_request_list import V1alpha3ResourcePoolStatusRequestList
from kubernetes.client.models.v1alpha3_resource_pool_status_request_spec import V1alpha3ResourcePoolStatusRequestSpec
from kubernetes.client.models.v1alpha3_resource_pool_status_request_status import V1alpha3ResourcePoolStatusRequestStatus
from kubernetes.client.models.v1beta1_allocated_device_status import V1beta1AllocatedDeviceStatus
from kubernetes.client.models.v1beta1_allocation_result import V1beta1AllocationResult
from kubernetes.client.models.v1beta1_apply_configuration import V1beta1ApplyConfiguration
from kubernetes.client.models.v1beta1_basic_device import V1beta1BasicDevice
from kubernetes.client.models.v1beta1_cel_device_selector import V1beta1CELDeviceSelector
from kubernetes.client.models.v1beta1_capacity_request_policy import V1beta1CapacityRequestPolicy
from kubernetes.client.models.v1beta1_capacity_request_policy_range import V1beta1CapacityRequestPolicyRange
from kubernetes.client.models.v1beta1_capacity_requirements import V1beta1CapacityRequirements
from kubernetes.client.models.v1beta1_cluster_trust_bundle import V1beta1ClusterTrustBundle
from kubernetes.client.models.v1beta1_cluster_trust_bundle_list import V1beta1ClusterTrustBundleList
from kubernetes.client.models.v1beta1_cluster_trust_bundle_spec import V1beta1ClusterTrustBundleSpec
from kubernetes.client.models.v1beta1_counter import V1beta1Counter
from kubernetes.client.models.v1beta1_counter_set import V1beta1CounterSet
from kubernetes.client.models.v1beta1_device import V1beta1Device
from kubernetes.client.models.v1beta1_device_allocation_configuration import V1beta1DeviceAllocationConfiguration
from kubernetes.client.models.v1beta1_device_allocation_result import V1beta1DeviceAllocationResult
from kubernetes.client.models.v1beta1_device_attribute import V1beta1DeviceAttribute
from kubernetes.client.models.v1beta1_device_capacity import V1beta1DeviceCapacity
from kubernetes.client.models.v1beta1_device_claim import V1beta1DeviceClaim
from kubernetes.client.models.v1beta1_device_claim_configuration import V1beta1DeviceClaimConfiguration
from kubernetes.client.models.v1beta1_device_class import V1beta1DeviceClass
from kubernetes.client.models.v1beta1_device_class_configuration import V1beta1DeviceClassConfiguration
from kubernetes.client.models.v1beta1_device_class_list import V1beta1DeviceClassList
from kubernetes.client.models.v1beta1_device_class_spec import V1beta1DeviceClassSpec
from kubernetes.client.models.v1beta1_device_constraint import V1beta1DeviceConstraint
from kubernetes.client.models.v1beta1_device_counter_consumption import V1beta1DeviceCounterConsumption
from kubernetes.client.models.v1beta1_device_request import V1beta1DeviceRequest
from kubernetes.client.models.v1beta1_device_request_allocation_result import V1beta1DeviceRequestAllocationResult
from kubernetes.client.models.v1beta1_device_selector import V1beta1DeviceSelector
from kubernetes.client.models.v1beta1_device_sub_request import V1beta1DeviceSubRequest
from kubernetes.client.models.v1beta1_device_taint import V1beta1DeviceTaint
from kubernetes.client.models.v1beta1_device_toleration import V1beta1DeviceToleration
from kubernetes.client.models.v1beta1_ip_address import V1beta1IPAddress
from kubernetes.client.models.v1beta1_ip_address_list import V1beta1IPAddressList
from kubernetes.client.models.v1beta1_ip_address_spec import V1beta1IPAddressSpec
from kubernetes.client.models.v1beta1_json_patch import V1beta1JSONPatch
from kubernetes.client.models.v1beta1_lease_candidate import V1beta1LeaseCandidate
from kubernetes.client.models.v1beta1_lease_candidate_list import V1beta1LeaseCandidateList
from kubernetes.client.models.v1beta1_lease_candidate_spec import V1beta1LeaseCandidateSpec
from kubernetes.client.models.v1beta1_match_condition import V1beta1MatchCondition
from kubernetes.client.models.v1beta1_match_resources import V1beta1MatchResources
from kubernetes.client.models.v1beta1_mutating_admission_policy import V1beta1MutatingAdmissionPolicy
from kubernetes.client.models.v1beta1_mutating_admission_policy_binding import V1beta1MutatingAdmissionPolicyBinding
from kubernetes.client.models.v1beta1_mutating_admission_policy_binding_list import V1beta1MutatingAdmissionPolicyBindingList
from kubernetes.client.models.v1beta1_mutating_admission_policy_binding_spec import V1beta1MutatingAdmissionPolicyBindingSpec
from kubernetes.client.models.v1beta1_mutating_admission_policy_list import V1beta1MutatingAdmissionPolicyList
from kubernetes.client.models.v1beta1_mutating_admission_policy_spec import V1beta1MutatingAdmissionPolicySpec
from kubernetes.client.models.v1beta1_mutation import V1beta1Mutation
from kubernetes.client.models.v1beta1_named_rule_with_operations import V1beta1NamedRuleWithOperations
from kubernetes.client.models.v1beta1_network_device_data import V1beta1NetworkDeviceData
from kubernetes.client.models.v1beta1_node_allocatable_resource_mapping import V1beta1NodeAllocatableResourceMapping
from kubernetes.client.models.v1beta1_opaque_device_configuration import V1beta1OpaqueDeviceConfiguration
from kubernetes.client.models.v1beta1_param_kind import V1beta1ParamKind
from kubernetes.client.models.v1beta1_param_ref import V1beta1ParamRef
from kubernetes.client.models.v1beta1_parent_reference import V1beta1ParentReference
from kubernetes.client.models.v1beta1_pod_certificate_request import V1beta1PodCertificateRequest
from kubernetes.client.models.v1beta1_pod_certificate_request_list import V1beta1PodCertificateRequestList
from kubernetes.client.models.v1beta1_pod_certificate_request_spec import V1beta1PodCertificateRequestSpec
from kubernetes.client.models.v1beta1_pod_certificate_request_status import V1beta1PodCertificateRequestStatus
from kubernetes.client.models.v1beta1_resource_claim import V1beta1ResourceClaim
from kubernetes.client.models.v1beta1_resource_claim_consumer_reference import V1beta1ResourceClaimConsumerReference
from kubernetes.client.models.v1beta1_resource_claim_list import V1beta1ResourceClaimList
from kubernetes.client.models.v1beta1_resource_claim_spec import V1beta1ResourceClaimSpec
from kubernetes.client.models.v1beta1_resource_claim_status import V1beta1ResourceClaimStatus
from kubernetes.client.models.v1beta1_resource_claim_template import V1beta1ResourceClaimTemplate
from kubernetes.client.models.v1beta1_resource_claim_template_list import V1beta1ResourceClaimTemplateList
from kubernetes.client.models.v1beta1_resource_claim_template_spec import V1beta1ResourceClaimTemplateSpec
from kubernetes.client.models.v1beta1_resource_pool import V1beta1ResourcePool
from kubernetes.client.models.v1beta1_resource_slice import V1beta1ResourceSlice
from kubernetes.client.models.v1beta1_resource_slice_list import V1beta1ResourceSliceList
from kubernetes.client.models.v1beta1_resource_slice_spec import V1beta1ResourceSliceSpec
from kubernetes.client.models.v1beta1_service_cidr import V1beta1ServiceCIDR
from kubernetes.client.models.v1beta1_service_cidr_list import V1beta1ServiceCIDRList
from kubernetes.client.models.v1beta1_service_cidr_spec import V1beta1ServiceCIDRSpec
from kubernetes.client.models.v1beta1_service_cidr_status import V1beta1ServiceCIDRStatus
from kubernetes.client.models.v1beta1_storage_version_migration import V1beta1StorageVersionMigration
from kubernetes.client.models.v1beta1_storage_version_migration_list import V1beta1StorageVersionMigrationList
from kubernetes.client.models.v1beta1_storage_version_migration_spec import V1beta1StorageVersionMigrationSpec
from kubernetes.client.models.v1beta1_storage_version_migration_status import V1beta1StorageVersionMigrationStatus
from kubernetes.client.models.v1beta1_variable import V1beta1Variable
from kubernetes.client.models.v1beta1_volume_attributes_class import V1beta1VolumeAttributesClass
from kubernetes.client.models.v1beta1_volume_attributes_class_list import V1beta1VolumeAttributesClassList
from kubernetes.client.models.v1beta2_allocated_device_status import V1beta2AllocatedDeviceStatus
from kubernetes.client.models.v1beta2_allocation_result import V1beta2AllocationResult
from kubernetes.client.models.v1beta2_cel_device_selector import V1beta2CELDeviceSelector
from kubernetes.client.models.v1beta2_capacity_request_policy import V1beta2CapacityRequestPolicy
from kubernetes.client.models.v1beta2_capacity_request_policy_range import V1beta2CapacityRequestPolicyRange
from kubernetes.client.models.v1beta2_capacity_requirements import V1beta2CapacityRequirements
from kubernetes.client.models.v1beta2_counter import V1beta2Counter
from kubernetes.client.models.v1beta2_counter_set import V1beta2CounterSet
from kubernetes.client.models.v1beta2_device import V1beta2Device
from kubernetes.client.models.v1beta2_device_allocation_configuration import V1beta2DeviceAllocationConfiguration
from kubernetes.client.models.v1beta2_device_allocation_result import V1beta2DeviceAllocationResult
from kubernetes.client.models.v1beta2_device_attribute import V1beta2DeviceAttribute
from kubernetes.client.models.v1beta2_device_capacity import V1beta2DeviceCapacity
from kubernetes.client.models.v1beta2_device_claim import V1beta2DeviceClaim
from kubernetes.client.models.v1beta2_device_claim_configuration import V1beta2DeviceClaimConfiguration
from kubernetes.client.models.v1beta2_device_class import V1beta2DeviceClass
from kubernetes.client.models.v1beta2_device_class_configuration import V1beta2DeviceClassConfiguration
from kubernetes.client.models.v1beta2_device_class_list import V1beta2DeviceClassList
from kubernetes.client.models.v1beta2_device_class_spec import V1beta2DeviceClassSpec
from kubernetes.client.models.v1beta2_device_constraint import V1beta2DeviceConstraint
from kubernetes.client.models.v1beta2_device_counter_consumption import V1beta2DeviceCounterConsumption
from kubernetes.client.models.v1beta2_device_request import V1beta2DeviceRequest
from kubernetes.client.models.v1beta2_device_request_allocation_result import V1beta2DeviceRequestAllocationResult
from kubernetes.client.models.v1beta2_device_selector import V1beta2DeviceSelector
from kubernetes.client.models.v1beta2_device_sub_request import V1beta2DeviceSubRequest
from kubernetes.client.models.v1beta2_device_taint import V1beta2DeviceTaint
from kubernetes.client.models.v1beta2_device_taint_rule import V1beta2DeviceTaintRule
from kubernetes.client.models.v1beta2_device_taint_rule_list import V1beta2DeviceTaintRuleList
from kubernetes.client.models.v1beta2_device_taint_rule_spec import V1beta2DeviceTaintRuleSpec
from kubernetes.client.models.v1beta2_device_taint_rule_status import V1beta2DeviceTaintRuleStatus
from kubernetes.client.models.v1beta2_device_taint_selector import V1beta2DeviceTaintSelector
from kubernetes.client.models.v1beta2_device_toleration import V1beta2DeviceToleration
from kubernetes.client.models.v1beta2_exact_device_request import V1beta2ExactDeviceRequest
from kubernetes.client.models.v1beta2_network_device_data import V1beta2NetworkDeviceData
from kubernetes.client.models.v1beta2_node_allocatable_resource_mapping import V1beta2NodeAllocatableResourceMapping
from kubernetes.client.models.v1beta2_opaque_device_configuration import V1beta2OpaqueDeviceConfiguration
from kubernetes.client.models.v1beta2_resource_claim import V1beta2ResourceClaim
from kubernetes.client.models.v1beta2_resource_claim_consumer_reference import V1beta2ResourceClaimConsumerReference
from kubernetes.client.models.v1beta2_resource_claim_list import V1beta2ResourceClaimList
from kubernetes.client.models.v1beta2_resource_claim_spec import V1beta2ResourceClaimSpec
from kubernetes.client.models.v1beta2_resource_claim_status import V1beta2ResourceClaimStatus
from kubernetes.client.models.v1beta2_resource_claim_template import V1beta2ResourceClaimTemplate
from kubernetes.client.models.v1beta2_resource_claim_template_list import V1beta2ResourceClaimTemplateList
from kubernetes.client.models.v1beta2_resource_claim_template_spec import V1beta2ResourceClaimTemplateSpec
from kubernetes.client.models.v1beta2_resource_pool import V1beta2ResourcePool
from kubernetes.client.models.v1beta2_resource_slice import V1beta2ResourceSlice
from kubernetes.client.models.v1beta2_resource_slice_list import V1beta2ResourceSliceList
from kubernetes.client.models.v1beta2_resource_slice_spec import V1beta2ResourceSliceSpec
from kubernetes.client.models.v2_api_group_discovery import V2APIGroupDiscovery
from kubernetes.client.models.v2_api_group_discovery_list import V2APIGroupDiscoveryList
from kubernetes.client.models.v2_api_resource_discovery import V2APIResourceDiscovery
from kubernetes.client.models.v2_api_subresource_discovery import V2APISubresourceDiscovery
from kubernetes.client.models.v2_api_version_discovery import V2APIVersionDiscovery
from kubernetes.client.models.v2_container_resource_metric_source import V2ContainerResourceMetricSource
from kubernetes.client.models.v2_container_resource_metric_status import V2ContainerResourceMetricStatus
from kubernetes.client.models.v2_cross_version_object_reference import V2CrossVersionObjectReference
from kubernetes.client.models.v2_external_metric_source import V2ExternalMetricSource
from kubernetes.client.models.v2_external_metric_status import V2ExternalMetricStatus
from kubernetes.client.models.v2_hpa_scaling_policy import V2HPAScalingPolicy
from kubernetes.client.models.v2_hpa_scaling_rules import V2HPAScalingRules
from kubernetes.client.models.v2_horizontal_pod_autoscaler import V2HorizontalPodAutoscaler
from kubernetes.client.models.v2_horizontal_pod_autoscaler_behavior import V2HorizontalPodAutoscalerBehavior
from kubernetes.client.models.v2_horizontal_pod_autoscaler_condition import V2HorizontalPodAutoscalerCondition
from kubernetes.client.models.v2_horizontal_pod_autoscaler_list import V2HorizontalPodAutoscalerList
from kubernetes.client.models.v2_horizontal_pod_autoscaler_spec import V2HorizontalPodAutoscalerSpec
from kubernetes.client.models.v2_horizontal_pod_autoscaler_status import V2HorizontalPodAutoscalerStatus
from kubernetes.client.models.v2_metric_identifier import V2MetricIdentifier
from kubernetes.client.models.v2_metric_spec import V2MetricSpec
from kubernetes.client.models.v2_metric_status import V2MetricStatus
from kubernetes.client.models.v2_metric_target import V2MetricTarget
from kubernetes.client.models.v2_metric_value_status import V2MetricValueStatus
from kubernetes.client.models.v2_object_metric_source import V2ObjectMetricSource
from kubernetes.client.models.v2_object_metric_status import V2ObjectMetricStatus
from kubernetes.client.models.v2_pods_metric_source import V2PodsMetricSource
from kubernetes.client.models.v2_pods_metric_status import V2PodsMetricStatus
from kubernetes.client.models.v2_resource_metric_source import V2ResourceMetricSource
from kubernetes.client.models.v2_resource_metric_status import V2ResourceMetricStatus
from kubernetes.client.models.v2beta1_api_group_discovery import V2beta1APIGroupDiscovery
from kubernetes.client.models.v2beta1_api_group_discovery_list import V2beta1APIGroupDiscoveryList
from kubernetes.client.models.v2beta1_api_resource_discovery import V2beta1APIResourceDiscovery
from kubernetes.client.models.v2beta1_api_subresource_discovery import V2beta1APISubresourceDiscovery
from kubernetes.client.models.v2beta1_api_version_discovery import V2beta1APIVersionDiscovery
from kubernetes.client.models.version_info import VersionInfo



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class RbacV1Subject(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'api_group': 'str',
        'kind': 'str',
        'name': 'str',
        'namespace': 'str'
    }

    attribute_map = {
        'api_group': 'apiGroup',
        'kind': 'kind',
        'name': 'name',
        'namespace': 'namespace'
    }

    def __init__(self, api_group=None, kind=None, name=None, namespace=None, local_vars_configuration=None):  # noqa: E501
        """RbacV1Subject - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._api_group = None
        self._kind = None
        self._name = None
        self._namespace = None
        self.discriminator = None

        if api_group is not None:
            self.api_group = api_group
        self.kind = kind
        self.name = name
        if namespace is not None:
            self.namespace = namespace

    @property
    def api_group(self):
        """Gets the api_group of this RbacV1Subject.  # noqa: E501

        APIGroup holds the API group of the referenced subject. Defaults to \"\" for ServiceAccount subjects. Defaults to \"rbac.authorization.k8s.io\" for User and Group subjects.  # noqa: E501

        :return: The api_group of this RbacV1Subject.  # noqa: E501
        :rtype: str
        """
        return self._api_group

    @api_group.setter
    def api_group(self, api_group):
        """Sets the api_group of this RbacV1Subject.

        APIGroup holds the API group of the referenced subject. Defaults to \"\" for ServiceAccount subjects. Defaults to \"rbac.authorization.k8s.io\" for User and Group subjects.  # noqa: E501

        :param api_group: The api_group of this RbacV1Subject.  # noqa: E501
        :type api_group: str
        """

        self._api_group = api_group

    @property
    def kind(self):
        """Gets the kind of this RbacV1Subject.  # noqa: E501

        Kind of object being referenced. Values defined by this API group are \"User\", \"Group\", and \"ServiceAccount\". If the Authorizer does not recognized the kind value, the Authorizer should report an error.  # noqa: E501

        :return: The kind of this RbacV1Subject.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this RbacV1Subject.

        Kind of object being referenced. Values defined by this API group are \"User\", \"Group\", and \"ServiceAccount\". If the Authorizer does not recognized the kind value, the Authorizer should report an error.  # noqa: E501

        :param kind: The kind of this RbacV1Subject.  # noqa: E501
        :type kind: str
        """
        if self.local_vars_configuration.client_side_validation and kind is None:  # noqa: E501
            raise ValueError("Invalid value for `kind`, must not be `None`")  # noqa: E501

        self._kind = kind

    @property
    def name(self):
        """Gets the name of this RbacV1Subject.  # noqa: E501

        Name of the object being referenced.  # noqa: E501

        :return: The name of this RbacV1Subject.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RbacV1Subject.

        Name of the object being referenced.  # noqa: E501

        :param name: The name of this RbacV1Subject.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def namespace(self):
        """Gets the namespace of this RbacV1Subject.  # noqa: E501

        Namespace of the referenced object.  If the object kind is non-namespace, such as \"User\" or \"Group\", and this value is not empty the Authorizer should report an error.  # noqa: E501

        :return: The namespace of this RbacV1Subject.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this RbacV1Subject.

        Namespace of the referenced object.  If the object kind is non-namespace, such as \"User\" or \"Group\", and this value is not empty the Authorizer should report an error.  # noqa: E501

        :param namespace: The namespace of this RbacV1Subject.  # noqa: E501
        :type namespace: str
        """

        self._namespace = namespace

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RbacV1Subject):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RbacV1Subject):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1VolumeProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cluster_trust_bundle': 'V1ClusterTrustBundleProjection',
        'config_map': 'V1ConfigMapProjection',
        'downward_api': 'V1DownwardAPIProjection',
        'pod_certificate': 'V1PodCertificateProjection',
        'secret': 'V1SecretProjection',
        'service_account_token': 'V1ServiceAccountTokenProjection'
    }

    attribute_map = {
        'cluster_trust_bundle': 'clusterTrustBundle',
        'config_map': 'configMap',
        'downward_api': 'downwardAPI',
        'pod_certificate': 'podCertificate',
        'secret': 'secret',
        'service_account_token': 'serviceAccountToken'
    }

    def __init__(self, cluster_trust_bundle=None, config_map=None, downward_api=None, pod_certificate=None, secret=None, service_account_token=None, local_vars_configuration=None):  # noqa: E501
        """V1VolumeProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._cluster_trust_bundle = None
        self._config_map = None
        self._downward_api = None
        self._pod_certificate = None
        self._secret = None
        self._service_account_token = None
        self.discriminator = None

        if cluster_trust_bundle is not None:
            self.cluster_trust_bundle = cluster_trust_bundle
        if config_map is not None:
            self.config_map = config_map
        if downward_api is not None:
            self.downward_api = downward_api
        if pod_certificate is not None:
            self.pod_certificate = pod_certificate
        if secret is not None:
            self.secret = secret
        if service_account_token is not None:
            self.service_account_token = service_account_token

    @property
    def cluster_trust_bundle(self):
        """Gets the cluster_trust_bundle of this V1VolumeProjection.  # noqa: E501


        :return: The cluster_trust_bundle of this V1VolumeProjection.  # noqa: E501
        :rtype: V1ClusterTrustBundleProjection
        """
        return self._cluster_trust_bundle

    @cluster_trust_bundle.setter
    def cluster_trust_bundle(self, cluster_trust_bundle):
        """Sets the cluster_trust_bundle of this V1VolumeProjection.


        :param cluster_trust_bundle: The cluster_trust_bundle of this V1VolumeProjection.  # noqa: E501
        :type cluster_trust_bundle: V1ClusterTrustBundleProjection
        """

        self._cluster_trust_bundle = cluster_trust_bundle

    @property
    def config_map(self):
        """Gets the config_map of this V1VolumeProjection.  # noqa: E501


        :return: The config_map of this V1VolumeProjection.  # noqa: E501
        :rtype: V1ConfigMapProjection
        """
        return self._config_map

    @config_map.setter
    def config_map(self, config_map):
        """Sets the config_map of this V1VolumeProjection.


        :param config_map: The config_map of this V1VolumeProjection.  # noqa: E501
        :type config_map: V1ConfigMapProjection
        """

        self._config_map = config_map

    @property
    def downward_api(self):
        """Gets the downward_api of this V1VolumeProjection.  # noqa: E501


        :return: The downward_api of this V1VolumeProjection.  # noqa: E501
        :rtype: V1DownwardAPIProjection
        """
        return self._downward_api

    @downward_api.setter
    def downward_api(self, downward_api):
        """Sets the downward_api of this V1VolumeProjection.


        :param downward_api: The downward_api of this V1VolumeProjection.  # noqa: E501
        :type downward_api: V1DownwardAPIProjection
        """

        self._downward_api = downward_api

    @property
    def pod_certificate(self):
        """Gets the pod_certificate of this V1VolumeProjection.  # noqa: E501


        :return: The pod_certificate of this V1VolumeProjection.  # noqa: E501
        :rtype: V1PodCertificateProjection
        """
        return self._pod_certificate

    @pod_certificate.setter
    def pod_certificate(self, pod_certificate):
        """Sets the pod_certificate of this V1VolumeProjection.


        :param pod_certificate: The pod_certificate of this V1VolumeProjection.  # noqa: E501
        :type pod_certificate: V1PodCertificateProjection
        """

        self._pod_certificate = pod_certificate

    @property
    def secret(self):
        """Gets the secret of this V1VolumeProjection.  # noqa: E501


        :return: The secret of this V1VolumeProjection.  # noqa: E501
        :rtype: V1SecretProjection
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this V1VolumeProjection.


        :param secret: The secret of this V1VolumeProjection.  # noqa: E501
        :type secret: V1SecretProjection
        """

        self._secret = secret

    @property
    def service_account_token(self):
        """Gets the service_account_token of this V1VolumeProjection.  # noqa: E501


        :return: The service_account_token of this V1VolumeProjection.  # noqa: E501
        :rtype: V1ServiceAccountTokenProjection
        """
        return self._service_account_token

    @service_account_token.setter
    def service_account_token(self, service_account_token):
        """Sets the service_account_token of this V1VolumeProjection.


        :param service_account_token: The service_account_token of this V1VolumeProjection.  # noqa: E501
        :type service_account_token: V1ServiceAccountTokenProjection
        """

        self._service_account_token = service_account_token

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1VolumeProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1VolumeProjection):
            return True

        return self.to_dict() != other.to_dict()



# Copyright 2026 The Kubernetes Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .cache import ObjectCache, _meta_namespace_key
from .informer import SharedInformer, ADDED, MODIFIED, DELETED, BOOKMARK, ERROR

__all__ = [
    "ObjectCache",
    "_meta_namespace_key",
    "SharedInformer",
    "ADDED",
    "MODIFIED",
    "DELETED",
    "BOOKMARK",
    "ERROR",
]



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V2APISubresourceDiscovery(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'subresource': 'str',
        'response_kind': 'IoK8sApimachineryPkgApisMetaV1GroupVersionKind',
        'accepted_types': 'list[IoK8sApimachineryPkgApisMetaV1GroupVersionKind]',
        'verbs': 'list[str]'
    }

    attribute_map = {
        'subresource': 'subresource',
        'response_kind': 'responseKind',
        'accepted_types': 'acceptedTypes',
        'verbs': 'verbs'
    }

    def __init__(self, subresource=None, response_kind=None, accepted_types=None, verbs=None, local_vars_configuration=None):  # noqa: E501
        """V2APISubresourceDiscovery - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._subresource = None
        self._response_kind = None
        self._accepted_types = None
        self._verbs = None
        self.discriminator = None

        self.subresource = subresource
        if response_kind is not None:
            self.response_kind = response_kind
        if accepted_types is not None:
            self.accepted_types = accepted_types
        self.verbs = verbs

    @property
    def subresource(self):
        """Gets the subresource of this V2APISubresourceDiscovery.  # noqa: E501

        subresource is the name of the subresource.  # noqa: E501

        :return: The subresource of this V2APISubresourceDiscovery.  # noqa: E501
        :rtype: str
        """
        return self._subresource

    @subresource.setter
    def subresource(self, subresource):
        """Sets the subresource of this V2APISubresourceDiscovery.

        subresource is the name of the subresource.  # noqa: E501

        :param subresource: The subresource of this V2APISubresourceDiscovery.  # noqa: E501
        :type subresource: str
        """
        if self.local_vars_configuration.client_side_validation and subresource is None:  # noqa: E501
            raise ValueError("Invalid value for `subresource`, must not be `None`")  # noqa: E501

        self._subresource = subresource

    @property
    def response_kind(self):
        """Gets the response_kind of this V2APISubresourceDiscovery.  # noqa: E501


        :return: The response_kind of this V2APISubresourceDiscovery.  # noqa: E501
        :rtype: IoK8sApimachineryPkgApisMetaV1GroupVersionKind
        """
        return self._response_kind

    @response_kind.setter
    def response_kind(self, response_kind):
        """Sets the response_kind of this V2APISubresourceDiscovery.


        :param response_kind: The response_kind of this V2APISubresourceDiscovery.  # noqa: E501
        :type response_kind: IoK8sApimachineryPkgApisMetaV1GroupVersionKind
        """

        self._response_kind = response_kind

    @property
    def accepted_types(self):
        """Gets the accepted_types of this V2APISubresourceDiscovery.  # noqa: E501


        :return: The accepted_types of this V2APISubresourceDiscovery.  # noqa: E501
        :rtype: list[IoK8sApimachineryPkgApisMetaV1GroupVersionKind]
        """
        return self._accepted_types

    @accepted_types.setter
    def accepted_types(self, accepted_types):
        """Sets the accepted_types of this V2APISubresourceDiscovery.


        :param accepted_types: The accepted_types of this V2APISubresourceDiscovery.  # noqa: E501
        :type accepted_types: list[IoK8sApimachineryPkgApisMetaV1GroupVersionKind]
        """

        self._accepted_types = accepted_types

    @property
    def verbs(self):
        """Gets the verbs of this V2APISubresourceDiscovery.  # noqa: E501

        verbs is a list of supported API operation types  # noqa: E501

        :return: The verbs of this V2APISubresourceDiscovery.  # noqa: E501
        :rtype: list[str]
        """
        return self._verbs

    @verbs.setter
    def verbs(self, verbs):
        """Sets the verbs of this V2APISubresourceDiscovery.

        verbs is a list of supported API operation types  # noqa: E501

        :param verbs: The verbs of this V2APISubresourceDiscovery.  # noqa: E501
        :type verbs: list[str]
        """
        if self.local_vars_configuration.client_side_validation and verbs is None:  # noqa: E501
            raise ValueError("Invalid value for `verbs`, must not be `None`")  # noqa: E501

        self._verbs = verbs

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V2APISubresourceDiscovery):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V2APISubresourceDiscovery):
            return True

        return self.to_dict() != other.to_dict()



# Copyright 2018 The Kubernetes Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import

from .create_from_yaml import (FailToCreateError, create_from_dict,
                               create_from_yaml, create_from_directory)
from .quantity import parse_quantity
from .duration import parse_duration
from .metrics import (get_nodes_metrics, get_pods_metrics,
                      get_pods_metrics_in_all_namespaces)



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1FCVolumeSource(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'fs_type': 'str',
        'lun': 'int',
        'read_only': 'bool',
        'target_wwns': 'list[str]',
        'wwids': 'list[str]'
    }

    attribute_map = {
        'fs_type': 'fsType',
        'lun': 'lun',
        'read_only': 'readOnly',
        'target_wwns': 'targetWWNs',
        'wwids': 'wwids'
    }

    def __init__(self, fs_type=None, lun=None, read_only=None, target_wwns=None, wwids=None, local_vars_configuration=None):  # noqa: E501
        """V1FCVolumeSource - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._fs_type = None
        self._lun = None
        self._read_only = None
        self._target_wwns = None
        self._wwids = None
        self.discriminator = None

        if fs_type is not None:
            self.fs_type = fs_type
        if lun is not None:
            self.lun = lun
        if read_only is not None:
            self.read_only = read_only
        if target_wwns is not None:
            self.target_wwns = target_wwns
        if wwids is not None:
            self.wwids = wwids

    @property
    def fs_type(self):
        """Gets the fs_type of this V1FCVolumeSource.  # noqa: E501

        fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. \"ext4\", \"xfs\", \"ntfs\". Implicitly inferred to be \"ext4\" if unspecified.  # noqa: E501

        :return: The fs_type of this V1FCVolumeSource.  # noqa: E501
        :rtype: str
        """
        return self._fs_type

    @fs_type.setter
    def fs_type(self, fs_type):
        """Sets the fs_type of this V1FCVolumeSource.

        fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. \"ext4\", \"xfs\", \"ntfs\". Implicitly inferred to be \"ext4\" if unspecified.  # noqa: E501

        :param fs_type: The fs_type of this V1FCVolumeSource.  # noqa: E501
        :type fs_type: str
        """

        self._fs_type = fs_type

    @property
    def lun(self):
        """Gets the lun of this V1FCVolumeSource.  # noqa: E501

        lun is Optional: FC target lun number  # noqa: E501

        :return: The lun of this V1FCVolumeSource.  # noqa: E501
        :rtype: int
        """
        return self._lun

    @lun.setter
    def lun(self, lun):
        """Sets the lun of this V1FCVolumeSource.

        lun is Optional: FC target lun number  # noqa: E501

        :param lun: The lun of this V1FCVolumeSource.  # noqa: E501
        :type lun: int
        """

        self._lun = lun

    @property
    def read_only(self):
        """Gets the read_only of this V1FCVolumeSource.  # noqa: E501

        readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.  # noqa: E501

        :return: The read_only of this V1FCVolumeSource.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this V1FCVolumeSource.

        readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.  # noqa: E501

        :param read_only: The read_only of this V1FCVolumeSource.  # noqa: E501
        :type read_only: bool
        """

        self._read_only = read_only

    @property
    def target_wwns(self):
        """Gets the target_wwns of this V1FCVolumeSource.  # noqa: E501

        targetWWNs is Optional: FC target worldwide names (WWNs)  # noqa: E501

        :return: The target_wwns of this V1FCVolumeSource.  # noqa: E501
        :rtype: list[str]
        """
        return self._target_wwns

    @target_wwns.setter
    def target_wwns(self, target_wwns):
        """Sets the target_wwns of this V1FCVolumeSource.

        targetWWNs is Optional: FC target worldwide names (WWNs)  # noqa: E501

        :param target_wwns: The target_wwns of this V1FCVolumeSource.  # noqa: E501
        :type target_wwns: list[str]
        """

        self._target_wwns = target_wwns

    @property
    def wwids(self):
        """Gets the wwids of this V1FCVolumeSource.  # noqa: E501

        wwids Optional: FC volume world wide identifiers (wwids) Either wwids or combination of targetWWNs and lun must be set, but not both simultaneously.  # noqa: E501

        :return: The wwids of this V1FCVolumeSource.  # noqa: E501
        :rtype: list[str]
        """
        return self._wwids

    @wwids.setter
    def wwids(self, wwids):
        """Sets the wwids of this V1FCVolumeSource.

        wwids Optional: FC volume world wide identifiers (wwids) Either wwids or combination of targetWWNs and lun must be set, but not both simultaneously.  # noqa: E501

        :param wwids: The wwids of this V1FCVolumeSource.  # noqa: E501
        :type wwids: list[str]
        """

        self._wwids = wwids

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1FCVolumeSource):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1FCVolumeSource):
            return True

        return self.to_dict() != other.to_dict()
